"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const immer_1 = __importDefault(require("immer"));
const inquirer_1 = __importDefault(require("inquirer"));
const profile_1 = require("../profile");
commander_1.program.command('new-profile [name]')
    .action(async (profileName) => {
    const existingProfiles = await (0, profile_1.listProfileNames)();
    const metaInfo = await inquirer_1.default.prompt([
        {
            type: 'text',
            name: 'name',
            message: 'What is the profile name?',
            default: profileName,
        },
        {
            type: 'confirm',
            name: 'isExtension',
            message: 'Is this based on an existing profile?',
            when: () => existingProfiles.length,
            default: false,
        },
        {
            type: 'list',
            name: 'extends',
            when: prev => prev.isExtension && existingProfiles.length,
            message: 'Which profile does this extend?',
            choices: existingProfiles,
        }
    ]);
    let baseProfile;
    if (metaInfo.extends) {
        baseProfile = await (0, profile_1.loadProfile)(metaInfo.extends);
    }
    const { baseUrl } = await inquirer_1.default.prompt([
        {
            type: 'text',
            name: 'baseUrl',
            message: 'What is the base url?',
            default: baseProfile?.baseUrl,
        }
    ]);
    const config = await (0, profile_1.getOpenIdConfiguration)({ baseUrl });
    const profileInfo = await (0, profile_1.buildProfile)({ baseProfile, config, baseUrl });
    const newProfile = (0, immer_1.default)(profileInfo, (draft) => {
        if (metaInfo.extends) {
            draft.extends = metaInfo.extends;
        }
        if (baseProfile) {
            for (const key of Object.keys(draft)) {
                // @ts-ignore
                if (draft[key] === baseProfile[key]) {
                    // @ts-ignore
                    delete draft.key;
                }
            }
        }
    });
    await (0, profile_1.saveProfile)(metaInfo.name, newProfile);
});
