"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveProfile = exports.loadProfile = exports.listProfileNames = void 0;
__exportStar(require("./getOpenIdConfiguration"), exports);
__exportStar(require("./profile"), exports);
__exportStar(require("./buildProfile"), exports);
const os_1 = require("os");
const path_1 = require("path");
const fsp = __importStar(require("fs/promises"));
const fs = __importStar(require("fs"));
const inquirer_1 = __importDefault(require("inquirer"));
const profileFileName = (0, path_1.join)((0, os_1.homedir)(), '.oauthrc');
const loadProfileFile = async (mustExist = true) => {
    if (!fs.existsSync(profileFileName)) {
        if (mustExist) {
            throw new Error('No profile file created');
        }
        return {
            profiles: {},
        };
    }
    const data = await fsp.readFile(profileFileName, 'utf-8');
    return JSON.parse(data);
};
const listProfileNames = async () => {
    const profileFile = await loadProfileFile(false);
    return Object.keys(profileFile.profiles);
};
exports.listProfileNames = listProfileNames;
const loadProfile = async (name) => {
    const profileSettings = await loadProfileFile();
    let profileName = name ?? profileSettings.default;
    const availableProfiles = Object.keys(profileSettings.profiles);
    if (profileName && !availableProfiles.includes(profileName)) {
        profileName = undefined;
    }
    const { selectedProfile } = await inquirer_1.default.prompt([
        {
            name: 'selectedProfile',
            type: 'list',
            message: 'Which profile do you want to use?',
            choices: availableProfiles,
        },
    ], { selectedProfile: profileName });
    profileName = selectedProfile;
    if (!profileName) {
        throw new Error('No profile name provided!');
    }
    if (!profileSettings?.profiles?.[profileName]) {
        throw new Error(`No profile named "${profileName}" was found`);
    }
    let profile = profileSettings.profiles[profileName];
    if (profile.extends) {
        const baseProfile = await (0, exports.loadProfile)(profile.extends);
        profile = {
            ...baseProfile,
            ...profile,
        };
    }
    return profile;
};
exports.loadProfile = loadProfile;
const saveProfile = async (name, profile) => {
    const profileFile = await loadProfileFile(false);
    profileFile.profiles[name] = profile;
    await fsp.writeFile(profileFileName, JSON.stringify(profileFile, null, 2), 'utf-8');
};
exports.saveProfile = saveProfile;
